----=============================================================================================================

local addonName = ...
local MINICURRENCY_VERSION = GetAddOnMetadata(addonName, "Version");

----=============================================================================================================

local MiniCurrency = CreateFrame("GameTooltip", "MiniCurrency", UIParent, "GameTooltipTemplate")
MiniCurrency:SetScript("OnEvent", function(self, event, ...) self:OnEvent(self, event, ...) end)
MiniCurrency:RegisterEvent("ADDON_LOADED") -- Needed for the position to get restored!
MiniCurrency:RegisterEvent("CURRENCY_DISPLAY_UPDATE")
MiniCurrency:RegisterEvent("CHAT_MSG_CURRENCY")


UIParent:HookScript("OnShow", function() MiniCurrency:Update() end)



--===== TEST EVENTS ===========================================================================================
--MiniCurrency:RegisterEvent("PLAYER_TRADE_CURRENCY")
--MiniCurrency:RegisterEvent("TRADE_CURRENCY_CHANGED")
--===== TEST EVENTS ===========================================================================================





--=============================================================================================================
hooksecurefunc("TokenFrame_Update", function() MiniCurrency:Update() end)
--=============================================================================================================

function MiniCurrency:OnEvent(self, event, ...)

	--DEFAULT_CHAT_FRAME:AddMessage(format("--- %s --- %s |cffFFFFFF- %s", self:GetName(), GetTime(), event), 1, 0, 0)

	if event == "ADDON_LOADED" then
		if select(1, ...) == addonName then
			DEFAULT_CHAT_FRAME:AddMessage(format("[%s] v%s loaded", addonName, MINICURRENCY_VERSION), 1, .48, 0)
			self:Init()
		end
		return
	end

	----------------------------------------------------------------
    	
	if event == "CHAT_MSG_CURRENCY" then
		PlaySoundFile("Sound\\INTERFACE\\iMoneyDialogClose.ogg")
		return
	end

	----------------------------------------------------------------
	
	if	event == "CURRENCY_DISPLAY_UPDATE" then
		self:Update()
		return
	end

end

--=============================================================================================================

function MiniCurrency:Init()

	if not self:IsUserPlaced() then
		self:SetPoint("CENTER")
	end

	self:SetMovable(true) -- This must be run on "ADDON_LOADED" for the position to get restored!
	self:RegisterForDrag("LeftButton")
	self:SetScript("OnMouseDown", 
		function(self, button)
			
			if button == "LeftButton" then
				--if ( IsAltKeyDown() ) then
					self:StartMoving()
				--end
			
			elseif button == "RightButton" then
				self.showAll = not self.showAll
				MiniCurrency_Settings.showAll = self.showAll
				self:Update()
			
			elseif button == "MiddleButton" then
				self.skin_nr = self.skin_nr + 1
				MiniCurrency_Settings.skin_nr = self.skin_nr
				self:Update()

			end
		end)

	self:SetScript("OnMouseUp", self.StopMovingOrSizing)

	if MiniCurrency_Settings == nil then
		MiniCurrency_Settings = { }
	end

	self.showAll = MiniCurrency_Settings.showAll or false
	self.skin_nr = MiniCurrency_Settings.skin_nr or 0

end

--=============================================================================================================

function MiniCurrency:Update()

	self:SetOwner(UIParent, "ANCHOR_PRESERVE")
	self:SetScale(.8)
	self:ClearLines()
--	self:SetText(" ") -- To make the first line not bigger than other ones!
	self:SetText(addonName)
	local anyWatched = false
	local cCount = GetCurrencyListSize()
	--print("cCount = " .. cCount)
	for index = 1, cCount do 
		local name, isHeader, isExpanded, isUnused, isWatched, count, icon, maximum, hasWeeklyLimit, currentWeeklyAmount, unknown = GetCurrencyListInfo(index)
		anyWatched = (anyWatched or isWatched)
		if isWatched and not isUnused then
			self:AddLine(format("|T%s:20|t %i", icon, count), 0.9, 1, 0.5)
			--self:AddDoubleLine(name .. "\n", format("%i |T%s:20|t", count, icon), 0.9, 1, 0.5, 0, 1, 0)
			--self:AddDoubleLine(name, format("%i |T%s:16:16:0:0:18:18:1:17:1:17|t", count, icon), 1, 1, 1, 1, 1, 1)
			--self:AddDoubleLine("\n", format("%i |T%s:20|t", count, icon), 0.9, 1, 0.5, 1, 1, 1)
			--self:AddDoubleLine(format(" %s\n", name), format("%i |T%s:20:20:0:0:22:22:1:21:1:21|t", count, icon), 1, 1, 0.62, 1, 1, 1)
		elseif not isHeader and self.showAll then
			self:AddLine(format("|T%s:20|t %i", icon, count), 0.5, 0.5, 0.5)
			--self:AddDoubleLine(name .. "\n", format("%i |T%s:20|t", count, icon), 0.5, 0.5, 0.5, 0.5, 0.5, 0.5)
		end
	end
	if not anyWatched and not self.showAll then
		_G["MiniCurrencyTextLeft1"]:SetTextHeight(14)
	else
		_G["MiniCurrencyTextLeft1"]:SetTextHeight(0.000001) -- To make the first line not bigger than other ones!
	end
	self:Show()
	self:ChangeSkin()

--	print(format("|cff00FFFFMiniCurrency CPU|r %.2f ms", GetFrameCPUUsage(self, true)))

end

--=============================================================================================================

function MiniCurrency:ChangeSkin()

	if not self.skin_nr or self.skin_nr > 4 then
		self.skin_nr = 0
	end
	
	local backdrop = {
			bgFile = "Interface/Tooltips/UI-Tooltip-Background",
			edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
			tile = true,
			tileSize = 16,
			edgeSize = 16,
			insets = { left = 4, right = 4, top = 4, bottom = 4, }
			}
	
	if self.skin_nr == 0 then
		self:SetBackdrop(backdrop)
		self:SetBackdropColor(0.09, 0.09, 0.19, 0.99)

	elseif self.skin_nr == 1 then
		self:SetBackdrop(backdrop)
		self:SetBackdropColor(0, 0, 0, 1)
		self:SetBackdropBorderColor(0, 0, 0, 0.4)

	elseif self.skin_nr == 2 then
		self:SetBackdrop(backdrop)
		self:SetBackdropColor(0, 0, 0, 0.5)
		self:SetBackdropBorderColor(0, 0, 0, 0.2)
	
	elseif self.skin_nr == 3 then
		backdrop.bgFile = nil
		self:SetBackdrop(backdrop)
		self:SetBackdropBorderColor(0, 0, 0, 0.2)
	
	elseif self.skin_nr == 4 then
		backdrop.bgFile = nil
		backdrop.edgeFile = nil
		self:SetBackdrop(backdrop)

	end
end

--=============================================================================================================

